@@ -11,6 +11,7 @@ from typing import Optional
 import requests
 import xattr
 from quera.utils.cache import cache, cached
+from quera.utils.validators import is_colab
 
 JUDGE_API = 'https://mirror.quera.org/judge_api/apikey-judge/'
 CONFIG_NAME = '.quera_config'
@@ -168,4 +169,5 @@ def submit_files(file_names: list = None):
 
     output_filename = "result.zip"
     compress(file_names, output_filename=output_filename)
-    submit(submitting_file_name=output_filename)
+    if is_colab():
+        submit(submitting_file_name=output_filename)
